Index: runtime/vm/regexp_parser.cc |
diff --git a/runtime/vm/regexp_parser.cc b/runtime/vm/regexp_parser.cc |
index 7b0e01a478def31d88085172c21432df03af6038..c4d471ae37f81f424ce2250bee71cba7e1a7dfaf 100644 |
--- a/runtime/vm/regexp_parser.cc |
+++ b/runtime/vm/regexp_parser.cc |
@@ -220,14 +220,14 @@ bool RegExpParser::ParseFunction(ParsedFunction *parsed_function) { |
VMTagScope tagScope(parsed_function->thread(), |
VMTag::kCompileParseRegExpTagId); |
Zone* zone = parsed_function->zone(); |
- JSRegExp& regexp = JSRegExp::Handle(parsed_function->function().regexp()); |
+ RegExp& regexp = RegExp::Handle(parsed_function->function().regexp()); |
const String& pattern = String::Handle(regexp.pattern()); |
const bool multiline = regexp.is_multi_line(); |
RegExpCompileData* compile_data = new(zone) RegExpCompileData(); |
if (!RegExpParser::ParseRegExp(pattern, multiline, compile_data)) { |
// Parsing failures are handled in the JSRegExp factory constructor. |
UNREACHABLE(); |
} |
@@ -220,14 +220,14 @@ bool RegExpParser::ParseFunction(ParsedFunction *parsed_function) { |
RegExpCompileData* compile_data = new(zone) RegExpCompileData(); |
if (!RegExpParser::ParseRegExp(pattern, multiline, compile_data)) { |
- // Parsing failures are handled in the JSRegExp factory constructor. |
+ // Parsing failures are handled in the RegExp factory constructor. |
UNREACHABLE(); |
} |